==> oxdperl-0.01.tar.gz: oxdperl-0.01/lib/OxdPerlModule.pm <==
package OxdPerlModule;

use 5.006;
use strict;
use warnings FATAL => 'all';
use OxdPackages::OxdConfig;
use OxdPackages::OxdRegister;
use OxdPackages::UpdateRegistration;
use OxdPackages::GetAuthorizationUrl;
use OxdPackages::GetTokenByCode;
use OxdPackages::GetUserInfo;
use OxdPackages::OxdLogout;
use OxdPackages::UmaRsProtect;
use OxdPackages::UmaRpAuthorizeRpt;
use OxdPackages::UmaRpGetGat;
use OxdPackages::UmaRpGetRpt;
use OxdPackages::UmaRsCheckAccess;

=head1 NAME

OxdPerlModule - The great new OxdPerlModule!

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use OxdPerlModule;

    my $foo = OxdPerlModule->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Gaurav Chhabra, C<< <gaurav.chhabra6785 at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-oxdperl at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=oxdperl>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc OxdPerlModule


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=oxdperl>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/oxdperl>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/oxdperl>

=item * Search CPAN

L<http://search.cpan.org/dist/oxdperl/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2017 Gluu.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of OxdPerlModule

==> oxdperl-0.02.tar.gz: oxdperl-0.02/lib/OxdPerlModule.pm <==
package OxdPerlModule;

use 5.006;
use strict;
use warnings FATAL => 'all';
use OxdPackages::OxdConfig;
use OxdPackages::OxdRegister;
use OxdPackages::OxdSetupClient;
use OxdPackages::GetClientToken;
use OxdPackages::UpdateRegistration;
use OxdPackages::GetAuthorizationUrl;
use OxdPackages::GetTokenByCode;
use OxdPackages::GetAccessTokenByRefreshToken;
use OxdPackages::GetUserInfo;
use OxdPackages::OxdLogout;
use OxdPackages::UmaRsProtect;
use OxdPackages::UmaRpGetRpt;
use OxdPackages::UmaRsCheckAccess;
use OxdPackages::UmaRpGetClaimsGatheringUrl;

=head1 NAME

OxdPerlModule - The great new OxdPerlModule!

=head1 VERSION

Version 0.02

=cut

our $VERSION = '0.02';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use OxdPerlModule;

    my $foo = OxdPerlModule->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Sobhan Panda, C<< <sobhan at centroxy.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-oxdperl at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=oxdperl>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc OxdPerlModule


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=oxdperl>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/oxdperl>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/oxdperl>

=item * Search CPAN

L<http://search.cpan.org/dist/oxdperl/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2017 Gluu.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of OxdPerlModule
